//Software exemplo para leitura de célula de carga
//Utilizando o shield OPS012 e célula de carga para 50.0kg
//Nesse software utilizaremos apenas a entrada AT1
//Serão implementadas as funções de tara e calibração

//Biblioteca para célula de carga
//É preciso instalar a biblioteca em "Gerenciar Bibliotecas..."
#include <HX711_ADC.h>

//Pinos para entrada de carga
const int pin_DOUT1 = 18;
const int pin_SCK1 = 5;

//chamada da biblioteca de leitura do conversor ADC
HX711_ADC Sensor1(pin_DOUT1, pin_SCK1);

//Variáveis de controle
long  CRG_Raw = 0;                   //Valor da saída crua do conversor ADC
long  CRG_Calibrado = 0;             //Valor de carga atual calibrado
long  CRG_Tara_Analog = 8765432;     //Valor analógico para tara 0.0kg (Os valores são arbitrários, apenas com o propósito demonstrativo)
long  CRG_Tara_Peso = 00;             //Valor do peso para tara 0.0kg (verificar que existe a casa decimal, mas sem ponto por se tratar de um valor inteiro)
long  CRG_Calib_Analog = 9345678;    //Valor analógico para calibração referente a 50.0kg (Os valores são arbitrários, apenas com o propósito demonstrativo)
long  CRG_Calib_Peso = 500;          //Valor do peso para calibração referente a 50.0kg (verificar que existe a casa decimal, mas sem ponto por se tratar de um valor inteiro)
int   CRG_Controle = 0;

void setup() {
  //Inicializa comunicações
  Serial.begin(115200); // (USB)
  
  //Inicialização da biblioteca HX711
  Sensor1.begin();
  Sensor1.start(2000, false);
  Sensor1.setCalFactor(1);
  
}

void loop() {

  //************************************************************************************
  //Leitura da entrada do conversor ADC
  //O valor de entrada tem 24 bits de resolução
  //************************************************************************************
  if (Sensor1.update()) {
    CRG_Raw = Sensor1.getData();
  }

  //Leitura do valor atual calibrado
  if (CRG_Controle == 0){
    //Nesse caso estamos calibrando para 0.0kg e 50.0kg
    CRG_Calibrado = map(CRG_Raw, CRG_Tara_Analog, CRG_Calib_Analog, CRG_Tara_Peso, CRG_Calib_Peso);
  }

  //Calibração da tara
  if (CRG_Controle == 1){
    CRG_Tara_Analog = CRG_Raw;
    CRG_Controle = 0;
  }

  //Calibração do peso
  if (CRG_Controle == 21){
    CRG_Calib_Analog = CRG_Raw;
    CRG_Controle = 0;
  }

}
